@@ -1,5 +1,7 @@
 #!/bin/sh
-BOARD_DIR="$(dirname $0)"
+set -eu
+
+BOARD_DIR="$(dirname "$0")"
 
 cp $BOARD_DIR/uEnv.txt $BINARIES_DIR/uEnv.txt
 
